pub struct MailSignal(/* private fields */);Expand description
The signal a client pings when mail may be waiting; see
Client::mail. Cheap to clone and hold apart from the client.
Implementations
Sourceimpl MailSignal
impl MailSignal